<html>
<head>
<title>Bibliography</title>
<link rel="stylesheet" type="text/css" href="pythia.css"/>
<link rel="shortcut icon" href="pythia32.gif"/>
</head>
<body>

<script language=javascript type=text/javascript>
function stopRKey(evt) {
var evt = (evt) ? evt : ((event) ? event : null);
var node = (evt.target) ? evt.target :((evt.srcElement) ? evt.srcElement : null);
if ((evt.keyCode == 13) && (node.type=="text"))
{return false;}
}

document.onkeypress = stopRKey;
</script>
<?php
if($_POST['saved'] == 1) {
if($_POST['filepath'] != "files/") {
echo "<font color='red'>SETTINGS SAVED TO FILE</font><br/><br/>"; }
else {
echo "<font color='red'>NO FILE SELECTED YET.. PLEASE DO SO </font><a href='SaveSettings.php'>HERE</a><br/><br/>"; }
}
?>

<form method='post' action='Bibliography.php'>

<h2>Bibliography</h2>

<dl>
	
<dt>Ali10</dt>
<dd>S. Alioli, P. Nason, C. Oleari, E. Re, JHEP 1006 (2010) 043,
[arXiv:1002.2581 [hep-ph]]</dd>

<dt>All08</dt>
<dd>B. Allanach et al., Comput. Phys.Commun. 180 (2009) 8
[arXiv:0801.0045 [hep-ph]]</dd>

<dt>Alt89</dt>
<dd>G. Altarelli, B. Mele and M. Ruiz-Altaba, 
Z. Phys. C45 (1989) 109</dd>

<dt>Alw06</dt>
<dd>J. Alwall et al., Comput. Phys. Commun. 176 (2007) 300
[hep-ph/0609017]</dd>

<dt>Alw07</dt>
<dd>J. Alwall et al., arXiv:0712.3311 [hep-ph]</dd> 

<dt>Alw11</dt>
<dd>J. Alwall, M. Herquet, F. Maltoni, O. Mattelaer, T. Stelzer, 
JHEP 1106 (2011) 128 [arXiv:1106.0522 [hep-ph]]</dd> 

<dt>ATL12</dt>
<dd>ATLAS Collaboration, ATL-PHYS-PUB-2012-003</dd> 

<dt>And83</dt>
<dd>B. Andersson, G. Gustafson, G. Ingelman and T. Sj&ouml;strand,
Phys. Rep. 97 (1983) 31</dd>

<dt>Ask09</dt> 
<dd>S. Ask, Eur. Phys. J. C60 (2009) 509</dd>

<dt>Ask10</dt> 
<dd>S. Ask et al., Comput. Phys. Commun. 181 (2010) 1593
[arXiv:0912.4233v1 [hep-ph]] </dd>

<dt>Ask11</dt>
<dd>S. Ask, J.H. Collins, J.R. Forshaw, K. Joshi, A.D. Pilkington,
JHEP 1201 (2012) 018 [arXiv:1108.2396 [hep-ph]] </dd>

<dt>Azu05</dt> 
<dd>G. Azuelos, P.-H. Beauchemin and C.P. Burgess, J. Phys. G31 (2005) 1</dd>

<dt>Bar94</dt>
<dd>E. Barberio and Z. Was, Comput. Phys.Commun. 79 (1994) 291

<dt>Bar06</dt>
<dd>M. Bargiotti, talk at the HERA4LHC workshop,
http://mbargiot.web.cern.ch/mbargiot/talks/

<dt>Bau90</dt>
<dd>U. Baur, M. Spira and P. M. Zerwas, Phys. Rev. D42 (1990) 815;
<br/>C. Berger et al., CERN Yellow Reports 90-10, Vol. II, p.1014</dd> 

<dt>Bel10</dt>
<dd>G. Bella et al., arXiv:1004.1649 [hep-ex],
<br/>G. Bella et al., JHEP 1009 (2010) 025 [arXiv:1004.2432 [hep-ex]]</dd>

<dt>Ben85</dt>
<dd>H.-U. Bengtsson, W.-S. Hou, A. Soni and D.H. Stork, 
Phys. Rev. Lett. 55 (1985) 2762</dd>

<dt>Ben87</dt>
<dd>M. Bengtsson and T. Sj&ouml;strand, Phys.Lett. B185 (1987) 435,
Nucl. Phys. B289 (1987) 810</dd>

<dt>Ber81</dt>
<dd>F.A. Berends, R. Kleiss, P. De Causmaecker, R. Gastmans and T.T. Wu, 
Phys. Lett. 103B (1981) 124</dd>

<dt>Ber87</dt>
<dd>UA4 Collaboration, D. Bernard et al., Phys. Lett. B198 (1987) 583</dd>

<dt>Ber87a</dt>
<dd>E. Berger, J. Collins, D. Soper and G. Sterman, Nucl. Phys. B286 
(1987) 704;
<br/>K. Streng, CERN-TH.4949 (1988)</dd>

<dt>Ber12</dt>
<dd>Particle Data Group, J. Beringer et al., Phys. Rev. D86 (2012) 010001</dd> 

<dt>Bij01</dt> 
<dd>J. Bijnens et al., Phys. Lett. B503 (2001) 341</dd>

<dt>Boo01</dt>
<dd>E. Boos et al., in the Proceedings of the Workshop on Physics 
at TeV Colliders, Les Houches, France, 21 May - 1 Jun 2001 
[hep-ph/0109068]</dd>

<dt>Bow81</dt>
<dd>M.G. Bowler, Z. Phys. C11 (1981) 169</dd>

<dt>Boz07</dt>
<dd>G. Bozzi, B. Fuks, B. Herrmann, M. Klasen, Nucl. Phys. B787 (2007) 1
[arXiv:0704.1826 [hep-ph]]</dd> 

<dt>Bru93</dt>
<dd>P. Bruni and G. Ingelman, Phys. Lett. B311 (1993) 317</dd>

<dt>Buc10</dt>
<dd>A. Buckley et al., arXiv:1003.0694 [hep-ph]</dd>

<dt>Buc11</dt>
<dd>A. Buckley et al., Phys. Rep. 504 (2011) 145 
[arXiv:1101.2599 [hep-ph]]</dd>

<dt>Cac06</dt>
<dd>M. Cacciari and G.P. Salam, Phys. Lett. B641 (2006) 57
[hep-ph/0512210]</dd>

<dt>Cac08</dt>
<dd>M. Cacciari, G.P. Salam and G. Soyez, JHEP 04 (2008) 063
[arXiv:0802.1189 [hep-ph]]</dd>

<dt>Cac12</dt>
<dd>M. Cacciari, G.P. Salam and G. Soyez, Eur. Phys. J. C72 (2012) 1896
[arXiv:1111.6097 [hep-ph]]</dd>

<dt>Cah82</dt>
<dd>R. Cahn, Z. Physik C15 (1982) 253</dd>

<dt>Car10</dt>
<dd>L. Carloni and T. Sj&ouml;strand, JHEP 1009 (2010) 105 
[arXiv:1006.2911 [hep-ph]] </dd>

<dt>Car11</dt>
<dd>L. Carloni, J. Rathsman and T. Sj&ouml;strand,
JHEP 1104 (2011) 091 [arXiv:1102.3795 [hep-ph]]</dd>

<dt>Cat91</dt>
<dd>S. Catani, G. Marchesini and B.R. Webber, 
Nucl.Phys. B349 (1991) 635</dd>

<dt>Che07</dt> 
<dd>K. Cheung, W.-Y. Keung and T.-C. Yuan, 
Phys. Rev. D76 (2007) 055003</dd>

<dt>Cie12</dt>
<dd>R. Ciesielski and K. Goulianos, arXiv:1205.1446 [hep-ph]</dd>

<dt>Cor09</dt>
<dd>R. Corke and T. Sj&ouml;strand, JHEP 1001 (2010) 035 
[arXiv:0911.1909 [hep-ph]]</dd>

<dt>Cor10</dt>
<dd>R. Corke and T. Sj&ouml;strand, Eur. Phys. J. C69 (2010) 1  
[arXiv:1003.2384 [hep-ph]]</dd>

<dt>Cor10a</dt>
<dd>R. Corke and T. Sj&ouml;strand, JHEP 1103 (2011) 032 
[arXiv:1011.1759 [hep-ph]]</dd>

<dt>Cor11</dt>
<dd>R. Corke and T. Sj&ouml;strand, JHEP 1105 (2011) 009 
[arXiv:1101.5953 [hep-ph]] </dd>

<dt>Dav01</dt> 
<dd>H. Davoudiasl, J.L. Hewett and T.G. Rizzo, Phys. Rev. D63 (2001) 075004</dd>

<dt>Dav10</dt> 
<dd>N. Davidson, T. Przedzinski and Z. Was, arXiv:1011.0937 [hep-ph]</dd>

<dt>Des11</dt> 
<dd>N. Desai and P. Skands, Eur. Phys. J. C72 (2012) 2238 
[arXiv:1109.5852 [hep-ph]]</dd>

<dt>Dob01</dt>
<dd>M. Dobbs and J.B. Hansen, Comput. Phys. Commun. 134 (2001) 41</dd>

<dt>Don84</dt>
<dd>A. Donnachie and P.V. Landshoff, Nucl. Phys. B244 (1984) 322</dd>

<dt>Don92</dt>
<dd>A. Donnachie and P.V. Landshoff, Phys. Lett. B296 (1992) 227</dd>

<dt>Ede97</dt>
<dd>P. Eden and G. Gustafson, Z. Phys. C75 (1997) 41</dd>

<dt>Eic83</dt> 
<dd>E. Eichten, K. D. Lane and M. E. Peskin, Phys. Rev. Lett. 50 (1983) 811; 
<br/>P. Chiappetta and M. Perrottet, CERN Yellow Report 90-10, Vol. II, 
p. 806</dd>

<dt>Fra11</dt>
<dd>R. Franceschini, G.F. Giudice, P.P. Giardino, P. Lodone, A. Strumia, 
JHEP 1105 (2011) 092 [arXiv:1101.4919 [hep-ph]] </dd>
	
<dt>Fre11</dt>
<dd>R. Frederix, S. Frixione, V. Hirschi, F. Maltoni, R. Pittau, 
P. Torrielli, Phys.Lett. B701 (2011) 427 [arXiv:1104.5613 [hep-ph]]</dd>  
	
<dt>Fri02</dt>
<dd>S. Frixione and B.R. Webber, JHEP 0206 (2002) 029 [hep-ph/0204244]</dd> 
 
<dt>Fuk11</dt>
<dd>B. Fuks, B. Hermann, and M. Klasen, Phys.Rev. D86 (2012) 015002
[arXiv:1112.4838]</dd>

<dt>Glu95</dt>
<dd>M. Gl&uuml;ck, E. Reya and A. Vogt, Z. Phys. C67 (1995) 433</dd>

<dt>Giu99</dt>
<dd>G.F. Giudice, R. Rattazzi and J.D. Wells, Nucl. Phys. B544 (1999) 3</dd>

<dt>Giu04</dt>
<dd>G.F. Giudice, T. Plehn and A. Strumia, Nucl. Phys. B706 (2005) 455</dd>

<dt>Gre07</dt>
<dd>D. Grellscheid and P. Richardson, arXiv:0810.1951 [hep-ph]</dd>

<dt>Gun86</dt>
<dd>J.F. Gunion and Z. Kunszt, Phys. Rev. D33 (1986) 665</dd>

<dt>Gus86</dt>
<dd>G. Gustafson, Phys. Lett. B175 (1986) 453;
<br/>G. Gustafson and U. Pettersson, Nucl. Phys. B306 (1988) 746;
<br/>L. L&ouml;nnblad, Comput. Phys. Commun. 71 (1992) 15</dd>

<dt>H1P06</dt>
<dd>H1 Collaboration, A. Aktas et al., Eur. Phys. J. C48 (2006) 715
[hep-ex/0606004]</dd>

<dt>H1P07</dt>
<dd>H1 Collaboration, A. Aktas et al., JHEP 0710 (2007) 042 
[arXiv:0708.3217 [hep-ex]]</dd>

<dt>Hew88</dt>
<dd>J.L. Hewett and S. Pakvasa, Phys. Rev. D37 (1988) 3165</dd>

<dt>Hew99</dt>
<dd>J.L Hewett, Phys. Rev. Lett. 82 (1999) 4765 [hep-ph/9811356]</dd>

<dt>Hew07</dt> 
<dd>J. L. Hewett and T. G. Rizzo, JHEP 0712 (2007) 009</dd>

<dt>Hui97</dt>
<dd>K. Huitu, J. Maalampi, A. Pietil&auml; and M. Raidal, 
Nucl. Phys. B487 (1997) 27 and private communication;
<br/>G. Barenboim, K. Huitu, J. Maalampi and M. Raidal, 
Phys. Lett. B394 (1997) 132</dd>

<dt>Ilt12</dt>
<dd>P. Ilten, arXiv:1211.6730 [hep-ph], to appear in the proceedings of
Tau2012, Nagoya, Japan, 17-21 September 2012
 </dd>

<dt>Ing85</dt>
<dd>G.Ingelman and P. Schlein, Phys. Lett. B152 (1985) 256</dd>

<dt>Ing97</dt>
<dd>P.Bruni, A. Edin and G.Ingelman, 
see PomPyt homepage <a href="http://www.isv.uu.se/thep/MC/pompyt/"
target="page">http://www.isv.uu.se/thep/MC/pompyt/</a>
</dd>

<dt>Jad90</dt>
<dd>S. Jadach, J.H. Kuhn and Z. Was, Comput. Phys. Commun. 64 (1990) 275;
S. Jadach, Z. Was, R. Decker and J.H. Kuhn, Comput. Phys. Commun. 
76 (1993) 361</dd>

<dt>Jun95</dt>
<dd>H. Jung, Comput. Phys.Commun. 86 (1995) 147</dd>

<dt>Kas10</dt>
<dd>T. Kasemets, LU TP 10-03, arXiv:1002.4376 [hep-ph];
<br>T. Kasemets and T. Sj&ouml;strand, Eur. Phys. J. C69 (2010) 19 
[arXiv:1007.0897v1 [hep-ph]]</dd>

<dt>Kle89</dt>
<dd>R. Kleiss et al., in `Z physics at LEP 1', 
eds. G. Altarelli, R. Kleiss and C. Verzegnassi, 
CERN 89-08 (Geneva, 1989), Vol. 3, p. 143</dd>

<dt>Kra04</dt>
<dd>A. Kraan, Eur. Phys. J. C37 (2004) 91</dd>

<dt>Kra08</dt>
<dd>A. Kraan, arXiv:0807.3123 [hep-ex]</dd>
 
<dt>Kum08</dt>
<dd>M.C. Kumar, P. Mathews, V. Ravindran and A. Tripathi, 
Phys. Rev. D77 (2008) 055013</dd>
 
<dt>Lai00</dt>
<dd>CTEQ Collaboration, H.L. Lai et al., 
Eur. Phys. J. C12 (2000) 375</dd>
 
<dt>Lon95</dt>
<dd>L. L&ouml;nnblad and T. Sj&ouml;strand, Phys. Lett. B351 (1995) 293, 
Eur. Phys. J. C2 (1998) 165</dd>

<dt>Lon01</dt>
<dd> L. L&ouml;nnblad, JHEP 05 (2002) 046 [hep-ph/0112284]</dd>

<dt>Lon11</dt>
<dd>L. L&ouml;nnblad and S. Prestel, JHEP 03 (2012) 019, arXiv:1109.4829 
[hep-ph]</dd> 

<dt>Lon12</dt>
<dd>L. L&ouml;nnblad and S. Prestel, JHEP 02 (2013) 094, 
arXiv:1211.4827 [hep-ph]</dd> 

<dt>Lon12a</dt>
<dd>L. L&ouml;nnblad, Eur. Phys. J. C73 (2013) 2350,
arXiv:1211.7204 [hep-ph]</dd> 

<dt>Lon13</dt>
<dd>L. L&ouml;nnblad and S. Prestel, JHEP 1303 (2013) 166,
arXiv:1211.7278 [hep-ph]</dd> 

<dt>Mac07</dt>
<dd>R. Mackeprang and A. Rizzi, Eur. Phys. J. C50 (2007) 353</dd>

<dt>Man02</dt>
<dd>M. Mangano,
<a href="http://www-cpd.fnal.gov/personal/mrenna/tuning/nov2002/mlm.pdf.gz">
"The so-called MLM prescription for ME/PS matching."
</a>, presented at the Fermilab ME/MC Tuning Workshop, October 4, 2002.
</dd>

<dt>Man03</dt>
<dd>M. L. Mangano, M. Moretti, F. Piccinini, R. Pittau and A. D. Polosa,
JHEP 0307 (2003) 001 [hep-ph/0206293]</dd>
	
<dt>Man07</dt>
<dd>M.L. Mangano, M. Moretti, F. Piccinini, M. Treccani, 
JHEP 0701 (2007) 013 [hep-ph/0611129]</dd> 

<dt>Mar90</dt>
<dd>G. Marsaglia, A. Zaman and W.-W. Tsang, 
Stat. Prob. Lett. 9 (1990) 35</dd>

<dt>Mar05</dt>
<dd>A.D. Martin, R.G. Roberts, W.J. Stirling and R.S. Thorne, 
Eur. Phys. J. C39 (2005) 155</dd>

<dt>Miu99</dt>
<dd>G. Miu and T. Sj&ouml;strand, Phys. Lett. B449 (1999) 313</dd>

<dt>Nas00</dt>
<dd>P. Nason et al., in "Standard model physics (and more) at the LHC",
eds. G. Altarelli and M.L. Mangano, CERN 2000-004, p. 231
[hep-ph/0003142]</dd> 

<dt>Nas04</dt>
<dd>P. Nason, JHEP 0411 (2004) 040 [hep-ph/0409146]</dd> 

<dt>Nav10</dt>
<dd>S. Navin, arXiv:1005.3894 [hep-ph]</dd> 

<dt>Nor00</dt>
<dd>E. Norrbin and T. Sj&ouml;strand, Eur. Phys. J. C17 (2000) 137</dd> 

<dt>Nor01</dt>
 <dd>E. Norrbin and T. Sj&ouml;strand, Nucl. Phys. B603 (2001) 297</dd>
  
<dt>Pet83</dt>
<dd>C. Peterson, D. Schlatter, I. Schmitt and P. Zerwas, 
Phys. Rev. D27 (1983) 105</dd>

<dt>Riz08</dt> 
<dd>T. G. Rizzo, Phys. Lett. B665 (2008) 361</dd>

<dt>Sch94</dt>
<dd>G.A. Schuler and T. Sj&ouml;strand, Phys. Rev. D49 (1994) 2257</dd> 

<dt>Sch97</dt>
<dd>G.A. Schuler and T. Sj&ouml;strand, Z. Phys. C73 (1997) 677</dd> 

<dt>Sjo84</dt>
<dd>T. Sj&ouml;strand, Nucl. Phys. B248 (1984) 469</dd>

<dt>Sey95</dt>
<dd>M. Seymour, Phys. Lett. B354 (1995) 409</dd>

<dt>Sjo85</dt>
<dd>T. Sj&ouml;strand, Phys. Lett. 157B (1985) 321;
<br/>M. Bengtsson, T. Sj&ouml;strand and M. van Zijl, Z. Phys. C32 (1986) 67
</dd>

<dt>Sjo87</dt>
<dd>T. Sj&ouml;strand and M. van Zijl, Phys. Rev. D36 (1987) 2019</dd>

<dt>Sjo03</dt>
<dd>T. Sj&ouml;strand and P.Z. Skands, Nucl. Phys. B659 (2003) 243</dd> 

<dt>Sjo04</dt>
<dd>T. Sj&ouml;strand and P.Z. Skands, JHEP 03 (2004) 053</dd>

<dt>Sjo05</dt>
<dd>T. Sj&ouml;strand and P.Z. Skands, Eur. Phys. J. C39 (2005) 129</dd> 

<dt>Sjo06</dt>
<dd>T. Sj&ouml;strand, S. Mrenna and P.Z. Skands,
JHEP 05 (2006) 026 [hep-ph/0603175]</dd> 

<dt>Ska04</dt>
<dd>P. Skands et al., JHEP 07 (2004) 036 [hep-ph/0311123]</dd> 

<dt>Tul09</dt>
<dd> J. Tully, Monte Carlo simulations of hard QCD radiation, Doctoral Thesis,
Durham University (2009) </dd>

<dt>Wha05</dt>
<dd>M.R. Whalley, D. Bourilkov and R.C. Group,
in `HERA and the LHC', eds. A. De Roeck and H. Jung,
CERN-2005-014, p. 575 [hep-ph/0508110]</dd>

<dt>Yao06</dt>
<dd>Particle Data Group, W.-M. Yao et al., 
J. Phys. G33 (2006) 1</dd>

</dl>

</body>
</html>

<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
